@@ -43,7 +43,7 @@ tables_default_values <- list(
   layout = "autofit",
   width = 1,
   tab.lp = "tab:",
-  topcaption = FALSE,
+  topcaption = TRUE,
   caption = list(
     style = "Table Caption",
     pre = "Table ", sep = ": ",
@@ -131,6 +131,7 @@ get_reference_rdocx <- memoise(get_docx_uncached)
 #' * `style`: the Word stylename to use for tables.
 #' * `layout`: 'autofit' or 'fixed' algorithm. See \code{\link[officer]{table_layout}}.
 #' * `width`: value of the preferred width of the table in percent (base 1).
+#' * `topcaption`: caption will appear before (on top of) the table,
 #' * `tab.lp`: caption table sequence identifier. All table captions are supposed
 #' to have the same identifier. It makes possible to insert list of tables. It is
 #' also used to prefix your 'bookdown' cross-reference call; if `tab.lp` is set to
@@ -428,7 +429,8 @@ rdocx_document <- function(base_format = "rmarkdown::word_document",
          fig.align = plots$align,
          fig.style = plots$style,
          fig.lp = plots$fig.lp,
-         fig.topcaption = plots$topcaption
+         fig.topcaption = plots$topcaption,
+         is_rdocx_document = TRUE
          )
     )
   if(is.null(output_formats$knitr$knit_hooks)){
